@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 """Reader for a single worksheet."""
 from io import BytesIO
@@ -22,7 +22,9 @@ from openpyxl.worksheet.dimensions import (
 from openpyxl.worksheet.header_footer import HeaderFooter
 from openpyxl.worksheet.hyperlink import Hyperlink
 from openpyxl.worksheet.merge import MergeCells
+from openpyxl.worksheet.cell_range import CellRange
 from openpyxl.worksheet.page import PageMargins, PrintOptions, PrintPageSetup
+from openpyxl.worksheet.pagebreak import PageBreak
 from openpyxl.worksheet.protection import SheetProtection
 from openpyxl.worksheet.views import SheetViewList
 from openpyxl.worksheet.datavalidation import DataValidationList
@@ -34,6 +36,7 @@ from openpyxl.xml.constants import (
 )
 from openpyxl.xml.functions import safe_iterator, localname
 from openpyxl.styles import Color
+from openpyxl.styles import is_date_format
 from openpyxl.formatting import Rule
 from openpyxl.formatting.formatting import ConditionalFormatting
 from openpyxl.formula.translate import Translator
@@ -44,6 +47,7 @@ from openpyxl.utils import (
     column_index_from_string,
     coordinate_to_tuple,
     )
+from openpyxl.utils.datetime import from_excel, from_ISO8601
 from openpyxl.descriptors.excel import ExtensionList, Extension
 from openpyxl.worksheet.table import TablePartList
 
@@ -78,6 +82,7 @@ class WorkSheetParser(object):
 
     def __init__(self, ws, xml_source, shared_strings):
         self.ws = ws
+        self.epoch = ws.parent.epoch
         self.source = xml_source
         self.shared_strings = shared_strings
         self.guess_types = ws.parent.guess_types
@@ -112,12 +117,12 @@ class WorkSheetParser(object):
             #'{%s}sheet/{%s}sortState' % (SHEET_MAIN_NS, SHEET_MAIN_NS): ('sort_state', SortState),
             '{%s}sheetPr' % SHEET_MAIN_NS: ('sheet_properties', WorksheetProperties),
             '{%s}sheetViews' % SHEET_MAIN_NS: ('views', SheetViewList),
-            '{%s}sheetFormatPr' % SHEET_MAIN_NS: ('sheet_format', SheetFormatProperties)
+            '{%s}sheetFormatPr' % SHEET_MAIN_NS: ('sheet_format', SheetFormatProperties),
+            '{%s}rowBreaks' % SHEET_MAIN_NS: ('page_breaks', PageBreak),
         }
 
-        tags = dispatcher.keys()
         stream = _get_xml_iter(self.source)
-        it = iterparse(stream, tag=tags)
+        it = iterparse(stream, tag=dispatcher)
 
         for _, element in it:
             tag_name = element.tag
@@ -216,12 +221,18 @@ class WorkSheetParser(object):
         if value is not None:
             if data_type == 'n':
                 value = _cast_number(value)
+                if is_date_format(cell.number_format):
+                    data_type = 'd'
+                    value = from_excel(value, self.epoch)
+
             elif data_type == 'b':
                 value = bool(int(value))
             elif data_type == 's':
                 value = self.shared_strings[int(value)]
             elif data_type == 'str':
                 data_type = 's'
+            elif data_type == 'd':
+                value = from_ISO8601(value)
 
         else:
             if data_type == 'inlineStr':
@@ -234,14 +245,15 @@ class WorkSheetParser(object):
         if self.guess_types or value is None:
             cell.value = value
         else:
-            cell._value=value
-            cell.data_type=data_type
+            cell._value = value
+            cell.data_type = data_type
 
 
     def parse_merge(self, element):
         merged = MergeCells.from_tree(element)
-        for c in merged.mergeCell:
-            self.ws.merge_cells(c.ref)
+        self.ws.merged_cells.ranges = merged.mergeCell
+        for cr in merged.mergeCell:
+            self.ws._clean_merge_range(cr)
 
 
     def parse_column_dimensions(self, col):
@@ -285,7 +297,7 @@ class WorkSheetParser(object):
         for rule in cf.rules:
             if rule.dxfId is not None:
                 rule.dxf = self.differential_styles[rule.dxfId]
-            self.ws.conditional_formatting.add(cf.sqref, rule)
+            self.ws.conditional_formatting[cf] = rule
 
 
     def parse_sheet_protection(self, element):
