@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 """Write a .xlsx file."""
 
@@ -9,6 +9,7 @@ import re
 from zipfile import ZipFile, ZIP_DEFLATED
 
 # package imports
+from openpyxl.utils.exceptions import InvalidFileException
 from openpyxl.xml.constants import (
     ARC_SHARED_STRINGS,
     ARC_CONTENT_TYPES,
@@ -61,6 +62,7 @@ class ExcelWriter(object):
         self._images = []
         self._drawings = []
         self._comments = []
+        self._pivots = []
 
 
     def write_data(self):
@@ -122,6 +124,8 @@ class ExcelWriter(object):
 
     def _write_charts(self):
         # delegate to object
+        if len(self._charts) != len(set(self._charts)):
+            raise InvalidFileException("The same chart cannot be used in more than one worksheet")
         for chart in self._charts:
             self._archive.writestr(chart.path[1:], tostring(chart._write()))
             self.manifest.append(chart)
@@ -191,6 +195,8 @@ class ExcelWriter(object):
 
     def _write_worksheets(self):
 
+        pivot_caches = set()
+
         for idx, ws in enumerate(self.workbook.worksheets, 1):
 
             ws._id = idx
@@ -222,6 +228,18 @@ class ExcelWriter(object):
                 self.manifest.append(t)
                 ws._rels[t._rel_id].Target = t.path
 
+            for p in ws._pivots:
+                if p.cache not in pivot_caches:
+                    pivot_caches.add(p.cache)
+                    p.cache._id = len(pivot_caches)
+
+                self._pivots.append(p)
+                p._id = len(self._pivots)
+                p._write(self._archive, self.manifest)
+                self.workbook._pivots.append(p)
+                r = Relationship(Type=p.rel_type, Target=p.path)
+                ws._rels.append(r)
+
             if ws._rels:
                 tree = ws._rels.to_tree()
                 self._archive.writestr(rels_path, tostring(tree))
@@ -282,3 +300,15 @@ def save_virtual_workbook(workbook,):
     virtual_workbook = temp_buffer.getvalue()
     temp_buffer.close()
     return virtual_workbook
+
+
+def save_dump(workbook, filename):
+    """
+    Save a write-only workbook
+    """
+    archive = ZipFile(filename, 'w', ZIP_DEFLATED, allowZip64=True)
+    if workbook.worksheets == []:
+        workbook.create_sheet()
+    writer = ExcelWriter(workbook, archive)
+    writer.save(filename)
+    return True
